@@ -27,16 +27,6 @@ class AsyncWebhookClient:
         auth: Optional[BasicAuth] = None,
         default_headers: Optional[Dict[str, str]] = None,
     ):
-        """API client for Incoming Webhooks and response_url
-        :param url: a complete URL to send data (e.g., https://hooks.slack.com/XXX)
-        :param timeout: request timeout (in seconds)
-        :param ssl: ssl.SSLContext to use for requests
-        :param proxy: proxy URL (e.g., localhost:9000, http://localhost:9000)
-        :param session: a complete aiohttp.ClientSession
-        :param trust_env_in_session: True/False for aiohttp.ClientSession
-        :param auth: Basic auth info for aiohttp.ClientSession
-        :param default_headers: request headers to add to all requests
-        """
         self.url = url
         self.timeout = timeout
         self.ssl = ssl
@@ -56,12 +46,15 @@ class AsyncWebhookClient:
         headers: Optional[Dict[str, str]] = None,
     ) -> WebhookResponse:
         """Performs a Slack API request and returns the result.
-        :param text: the text message (even when having blocks, setting this as well is recommended as it works as fallback)
-        :param attachments: a collection of attachments
-        :param blocks: a collection of Block Kit UI components
-        :param response_type: the type of message (either 'in_channel' or 'ephemeral')
-        :param headers: request headers to append only for this request
-        :return: API response
+
+        Args:
+            text: The text message (even when having blocks, setting this as well is recommended as it works as fallback)
+            attachments: A collection of attachments
+            blocks: A collection of Block Kit UI components
+            response_type: The type of message (either 'in_channel' or 'ephemeral')
+            headers: Request headers to append only for this request
+        Returns:
+            Webhook response
         """
         return await self.send_dict(
             body={
@@ -73,36 +66,18 @@ class AsyncWebhookClient:
             headers=headers,
         )
 
-    async def send_dict(
-        self, body: Dict[str, any], headers: Optional[Dict[str, str]] = None
-    ) -> WebhookResponse:
-        """Performs a Slack API request and returns the result.
-        :param body: json data structure (it's still a dict at this point),
-            if you give this argument, body_params and files will be skipped
-        :param headers: request headers to append only for this request
-        :return: API response
-        """
+    async def send_dict(self, body: Dict[str, any], headers: Optional[Dict[str, str]] = None) -> WebhookResponse:
         return await self._perform_http_request(
             body=_build_body(body),
             headers=_build_request_headers(self.default_headers, headers),
         )
 
-    async def _perform_http_request(
-        self, *, body: Dict[str, any], headers: Dict[str, str]
-    ) -> WebhookResponse:
-        """Performs an HTTP request and parses the response.
-        :param url: a complete URL to send data (e.g., https://hooks.slack.com/XXX)
-        :param body: request body data
-        :param headers: complete set of request headers
-        :return: API response
-        """
+    async def _perform_http_request(self, *, body: Dict[str, any], headers: Dict[str, str]) -> WebhookResponse:
         body = json.dumps(body)
         headers["Content-Type"] = "application/json;charset=utf-8"
 
         if self.logger.level <= logging.DEBUG:
-            self.logger.debug(
-                f"Sending a request - url: {self.url}, body: {body}, headers: {headers}"
-            )
+            self.logger.debug(f"Sending a request - url: {self.url}, body: {body}, headers: {headers}")
         session: Optional[ClientSession] = None
         use_running_session = self.session and not self.session.closed
         if use_running_session:
@@ -126,9 +101,7 @@ class AsyncWebhookClient:
                 try:
                     response_body = await res.text()
                 except aiohttp.ContentTypeError:
-                    self._logger.debug(
-                        f"No response data returned from the following API call: {self.url}."
-                    )
+                    self._logger.debug(f"No response data returned from the following API call: {self.url}.")
                 except json.decoder.JSONDecodeError as e:
                     message = f"Failed to parse the response body: {str(e)}"
                     raise SlackApiError(message, res)
